@@ -27,7 +27,7 @@ def openf(filename):
 def slist(inp,revers):
   if type(inp) is list:
     if revers:
-      return inp.sort(reverse=revers)
+      return inp.sort(reverse=True)
     else:
       return inp.sort()
 
@@ -49,15 +49,16 @@ def splist(inp):
   return lista
   
 def rmlist(liste):
-  if type(liste) is not list:
-    print("REQUIRED LIST, GOT: ", type(liste))
-    pass
-  else:
+  if type(liste) is list:
     liste = str(liste)
     liste = liste.replace('[','')
     liste = liste.replace(']','')
     liste = liste.replace(',','')
     liste = liste.replace("'", '')
+  else:
+    print("REQUIRED LIST, GOT: ", type(liste))
+    pass
+    
 def fwrite(file,text): 
   tempf = open(file,'a')
   tempf.close()
